@@ -2,16 +2,28 @@ import json
 from socket import create_connection
 from argparse import ArgumentParser
 
+qt5_config = {
+    "archives": [ "qtbase", "icu", "qtwebsockets", "qtdeclarative", "qtwebchannel", "qtlocation" ],
+    "modules": [ "qtwebengine" ]
+}
+
+qt6_config = {
+    "archives": [ "qtbase", "icu", "qtdeclarative" ],
+    "modules": [ "qtwebsockets", "qtwebengine", "qtwebchannel", "qtpositioning" ]
+}
+
 qt = [
     {
         "version": "5.15.2",
-        "archives": [ "qtbase", "icu", "qtwebsockets", "qtdeclarative", "qtwebchannel", "qtlocation" ],
-        "modules": [ "qtwebengine" ]
+        **qt5_config
     },
     {
         "version": "6.2.0",
-        "archives": [ "qtbase", "icu", "qtdeclarative" ],
-        "modules": [ "qtwebsockets", "qtwebengine", "qtwebchannel", "qtpositioning" ]
+        **qt6_config
+    },
+    {
+        "version": "6.5.0",
+        **qt6_config
     }
 ]
 
@@ -36,7 +48,7 @@ platforms = [
             },
             {
                 "name": "clang",
-                "versions": [ "11", "14", "dev" ]
+                "versions": [ "11", "14", "16", "17", "dev" ]
             }
         ]
     }
@@ -61,7 +73,7 @@ def get_base_image_for_compiler(compiler):
     if compiler == "gcc":
         return "gcc"
     elif compiler == "clang":
-        return "silkeh/clang"
+        return "debian"
     else:
         return None
 
