@@ -32,7 +32,13 @@ public:
                 emitReady(true);
             }
         }))
-        , mError(connect(socket, qOverload<QAbstractSocket::SocketError>(&QWebSocket::error), this, [this](auto error) {
+        , mError(connect(socket, qOverload<QAbstractSocket::SocketError>(
+#if QT_VERSION >= QT_VERSION_CHECK(6, 5, 0)
+                                     &QWebSocket::errorOccurred
+#else
+                                     &QWebSocket::error
+#endif
+                                     ), this, [this](auto error) {
             qWarning() << "QWebSocket failed to connect to a websocket server: " << error;
             emitReady(false);
         }))
